# Nim's Django Helpers
[![Build Status](https://travis-ci.org/nim65s/ndh.svg?branch=master)](https://travis-ci.org/nim65s/ndh)
[![Coverage Status](https://coveralls.io/repos/github/nim65s/ndh/badge.svg?branch=master)](https://coveralls.io/github/nim65s/ndh?branch=master)

## Requirements

- Python 3.6
- Django 2.0
- [django-autoslug](https://github.com/nim65s/django-autoslug) (waiting for
  https://github.com/neithere/django-autoslug/issues/31)
- [django-bootstrap3](https://github.com/dyve/django-bootstrap3) (will be django-bootstrap4 soon)
